==> brmo-stufbg204-1.6.3p1-sources.jar: nl/egem/stuf/stuf0204/TijdvakRelatie.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TijdvakRelatie complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TijdvakRelatie">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="begindatumRelatie" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/>
 *         &lt;element name="einddatumRelatie" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TijdvakRelatie", propOrder = {
    "begindatumRelatie",
    "einddatumRelatie"
})
public class TijdvakRelatie {

    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator begindatumRelatie;
    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator einddatumRelatie;

    /**
     * Gets the value of the begindatumRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getBegindatumRelatie() {
        return begindatumRelatie;
    }

    /**
     * Sets the value of the begindatumRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setBegindatumRelatie(DatumMetIndicator value) {
        this.begindatumRelatie = value;
    }

    /**
     * Gets the value of the einddatumRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getEinddatumRelatie() {
        return einddatumRelatie;
    }

    /**
     * Sets the value of the einddatumRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setEinddatumRelatie(DatumMetIndicator value) {
        this.einddatumRelatie = value;
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/stuf0204/TijdvakRelatie.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TijdvakRelatie complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TijdvakRelatie"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="begindatumRelatie" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/&gt;
 *         &lt;element name="einddatumRelatie" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicator"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TijdvakRelatie", propOrder = {
    "begindatumRelatie",
    "einddatumRelatie"
})
public class TijdvakRelatie {

    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator begindatumRelatie;
    @XmlElement(required = true, nillable = true)
    protected DatumMetIndicator einddatumRelatie;

    /**
     * Gets the value of the begindatumRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getBegindatumRelatie() {
        return begindatumRelatie;
    }

    /**
     * Sets the value of the begindatumRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setBegindatumRelatie(DatumMetIndicator value) {
        this.begindatumRelatie = value;
    }

    /**
     * Gets the value of the einddatumRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link DatumMetIndicator }
     *     
     */
    public DatumMetIndicator getEinddatumRelatie() {
        return einddatumRelatie;
    }

    /**
     * Sets the value of the einddatumRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link DatumMetIndicator }
     *     
     */
    public void setEinddatumRelatie(DatumMetIndicator value) {
        this.einddatumRelatie = value;
    }

}
